WordPartToken class

Typically a syllable. But also a syllable preceed or followed by non-word characters like: "abc"

Inheritance

Constructors

WordPartToken(String text)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeCurrent ↔ Size?
getter/setter pairinherited
sizeHyphen ↔ Size?
getter/setter pairinherited
sizeNoHyphen ↔ Size?
getter/setter pairinherited
text ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render() → String
override
toHyphenAndSize(String hyphen) → WordPartToken
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited